TermuxNotification

Struct TermuxNotification 

pub struct TermuxNotification { /* private fields */ }
Builder for termux-notification command

Implementations

Source

impl TermuxNotification

pub fn action_fn<F>(&mut self, f: F) -> &mut Self
where F: Fn() + Send + 'static,

Action to execute when pressing the notification

Panics

Panics if notification id not provided

pub fn on_delete_fn<F>(&mut self, f: F) -> &mut Self
where F: Fn() + Send + 'static,

Action to execute when the the notification is cleared

Panics

Panics if notification id not provided

pub fn button1_fn<L, F>(&mut self, label: L, f: F) -> &mut Self
where L: Into<String>, F: Fn() + Send + 'static,

Text and action for first notification button

Panics

Panics if notification id not provided

pub fn button2_fn<L, F>(&mut self, label: L, f: F) -> &mut Self
where L: Into<String>, F: Fn() + Send + 'static,

Text and action for second notification button

Panics

Panics if notification id not provided

pub fn button3_fn<L, F>(&mut self, label: L, f: F) -> &mut Self
where L: Into<String>, F: Fn() + Send + 'static,

Text and action for third notification button

Panics

Panics if notification id not provided

Source

impl TermuxNotification

pub fn new() -> Self

pub fn id(&mut self, id: impl Into<String>) -> &mut Self

Notification id (will overwrite any previous notification with the same id)

pub fn title(&mut self, title: impl Into<String>) -> &mut Self

Notification title to show

pub fn content(&mut self, content: impl Into<String>) -> &mut Self

Content to show in the notification.

pub fn icon(&mut self, icon: impl Into<String>) -> &mut Self

Set the icon that shows up in the status bar. View available icons at https://material.io/resources/icons/ (default icon: event_note)

pub fn alert_once(&mut self, alert_once: bool) -> &mut Self

Do not alert when the notification is edited

pub fn ongoing(&mut self, ongoing: bool) -> &mut Self

Pin the notification

pub fn action(&mut self, action: impl Into<String>) -> &mut Self

Action to execute when pressing the notification

pub fn on_delete(&mut self, on_delete: impl Into<String>) -> &mut Self

Action to execute when the the notification is cleared

pub fn button1( &mut self, label: impl Into<String>, action: impl Into<String>, ) -> &mut Self

Text and action for first notification button

pub fn button2( &mut self, label: impl Into<String>, action: impl Into<String>, ) -> &mut Self

Text and action for second notification button

pub fn button3( &mut self, label: impl Into<String>, action: impl Into<String>, ) -> &mut Self

Text and action for third notification button

pub fn show(&self) -> Result<RemoveHandle>

Shows notification via termux-notification command

Errors

Returns an error if command status not success

pub fn to_command(&self) -> Command

Builds termux-notification command