Struct termux_notification::TermuxNotification
source · pub struct TermuxNotification { /* private fields */ }Expand description
Builder for termux-notification command
Implementations
sourceimpl TermuxNotification
impl TermuxNotification
pub fn new() -> Self
sourcepub fn id(&mut self, id: impl Into<String>) -> &mut Self
pub fn id(&mut self, id: impl Into<String>) -> &mut Self
Notification id (will overwrite any previous notification with the same id)
sourcepub fn content(&mut self, content: impl Into<String>) -> &mut Self
pub fn content(&mut self, content: impl Into<String>) -> &mut Self
Content to show in the notification.
sourcepub fn icon(&mut self, icon: impl Into<String>) -> &mut Self
pub fn icon(&mut self, icon: impl Into<String>) -> &mut Self
Set the icon that shows up in the status bar.
View available icons at https://material.io/resources/icons/
(default icon: event_note)
sourcepub fn alert_once(&mut self, alert_once: bool) -> &mut Self
pub fn alert_once(&mut self, alert_once: bool) -> &mut Self
Do not alert when the notification is edited
sourcepub fn action(&mut self, action: impl Into<String>) -> &mut Self
pub fn action(&mut self, action: impl Into<String>) -> &mut Self
Action to execute when pressing the notification
sourcepub fn on_delete(&mut self, on_delete: impl Into<String>) -> &mut Self
pub fn on_delete(&mut self, on_delete: impl Into<String>) -> &mut Self
Action to execute when the the notification is cleared
Text and action for first notification button
Text and action for second notification button
Text and action for third notification button
sourcepub fn show(&self) -> Result<RemoveHandle>
pub fn show(&self) -> Result<RemoveHandle>
Shows notification via termux-notification command
Errors
Returns an error if command status not success
sourcepub fn to_command(&self) -> Command
pub fn to_command(&self) -> Command
Builds termux-notification command